/***************************************************************************
 *   Copyright (C) 2005 by Nicolas Ternisien                               *
 *   nicolas.ternisien@gmail.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/
#ifndef _XORG_READER_H_
#define _XORG_READER_H_

 
#include <tqobject.h>
#include <tqstringlist.h>
#include <tqmap.h>
#include <tqfile.h>
#include <tqpair.h>

#include <kurl.h>


#include "globals.h"

#include "defaultReader.h"


/**
 * @author Nicolas Ternisien
 */
class XorgReader : public DefaultReader {
	TQ_OBJECT
  
	
	public:
		XorgReader(TQObject *parent = 0, const char *name = 0);
		
		virtual ~XorgReader();
		
		virtual void initColumns(LogViewColumns* columns);
		
	protected:
		virtual LogLine* parseMessage(TQString& buffer, LogFile* originalFile);

		TQMap<TQString, LogLevel*> xorgLevels;
		
		void initializeTypeName();
		
		LogLevel* getTypeName(const TQString type);
		
		TQTime newLineTime;
		TQDate newLineDate;
		
		int lineCount;
};

#endif
